@@ -1553,14 +1553,18 @@ static void
 dialog_clicked (GtkWidget *widget, int button, gpointer data)
 {
 	PongUIInternal *ui = data;
-	/*int close = pong_gtk_object_get_int_data (widget, "close");*/
+	/*int ok = pong_gtk_object_get_int_data (widget, "ok");*/
 	int help = pong_gtk_object_get_int_data (widget, "help");
-	int revert = pong_gtk_object_get_int_data (widget, "revert");
+	int cancel = pong_gtk_object_get_int_data (widget, "cancel");
 
 	if (button == help) {
 		pong_ui_show_help (PONG_UI (ui));
-	} else if (button == revert) {
+	} else if (button == cancel) {
 		pong_ui_revert (PONG_UI (ui));
+		gnome_dialog_close (GNOME_DIALOG (widget));
+		/* note we have to do the revert before the close, because
+		 * note that 1) the revert change set has the lifetime of
+		 * the dialog 2) xml object might be dead by now */
 	} else {
 		gnome_dialog_close (GNOME_DIALOG (widget));
 	}
@@ -1617,41 +1621,46 @@ pong_dialog_new (PongUIInternal *ui,
 	    ! file->revert) {
 		dialog->wid = gnome_dialog_new (file->dialog_title, 
 						GNOME_STOCK_BUTTON_HELP,
-						GNOME_STOCK_BUTTON_CLOSE,
+						GNOME_STOCK_BUTTON_OK,
 						NULL);
-		pong_gtk_object_set_int_data (dialog->wid, "close", 1);
+		pong_gtk_object_set_int_data (dialog->wid, "ok", 1);
 		pong_gtk_object_set_int_data (dialog->wid, "help", 0);
-		pong_gtk_object_set_int_data (dialog->wid, "revert", 999);
+		pong_gtk_object_set_int_data (dialog->wid, "cancel", 999);
 		/* 999 is invalid, however, it can't be -1, as that's
 		 * given on dialog being closed by WM */
 	} else if (file->help_name != NULL &&
 		   file->revert) {
 		dialog->wid = gnome_dialog_new (file->dialog_title, 
 						GNOME_STOCK_BUTTON_HELP,
-						_("Revert"),
-						GNOME_STOCK_BUTTON_CLOSE,
-						NULL);
-		pong_gtk_object_set_int_data (dialog->wid, "close", 2);
+						GNOME_STOCK_BUTTON_CANCEL,
+						GNOME_STOCK_BUTTON_OK,
+						NULL,
+						/* Evil huh, but I want to
+						 * keep the Revert
+						 * translations so I don't want
+						 * to just delete this line */
+						N_("Revert"));
+		pong_gtk_object_set_int_data (dialog->wid, "ok", 2);
 		pong_gtk_object_set_int_data (dialog->wid, "help", 0);
-		pong_gtk_object_set_int_data (dialog->wid, "revert", 1);
+		pong_gtk_object_set_int_data (dialog->wid, "cancel", 1);
 	} else if (file->help_name == NULL &&
 		   file->revert) {
 		dialog->wid = gnome_dialog_new (file->dialog_title, 
-						_("Revert"),
-						GNOME_STOCK_BUTTON_CLOSE,
+						GNOME_STOCK_BUTTON_CANCEL,
+						GNOME_STOCK_BUTTON_OK,
 						NULL);
-		pong_gtk_object_set_int_data (dialog->wid, "close", 1);
+		pong_gtk_object_set_int_data (dialog->wid, "ok", 1);
 		pong_gtk_object_set_int_data (dialog->wid, "help", 999);
-		pong_gtk_object_set_int_data (dialog->wid, "revert", 0);
+		pong_gtk_object_set_int_data (dialog->wid, "cancel", 0);
 		/* 999 is invalid, however, it can't be -1, as that's
 		 * given on dialog being closed by WM */
 	} else {
 		dialog->wid = gnome_dialog_new (file->dialog_title, 
-						GNOME_STOCK_BUTTON_CLOSE,
+						GNOME_STOCK_BUTTON_OK,
 						NULL);
-		pong_gtk_object_set_int_data (dialog->wid, "close", 0);
+		pong_gtk_object_set_int_data (dialog->wid, "ok", 0);
 		pong_gtk_object_set_int_data (dialog->wid, "help", 999);
-		pong_gtk_object_set_int_data (dialog->wid, "revert", 999);
+		pong_gtk_object_set_int_data (dialog->wid, "cancel", 999);
 		/* 999 is invalid, however, it can't be -1, as that's
 		 * given on dialog being closed by WM */
 	}
